Index: src/mips/code-stubs-mips.cc |
diff --git a/src/mips/code-stubs-mips.cc b/src/mips/code-stubs-mips.cc |
index e1ea870aa6ced10b79d246edc673866d2a62e380..844958ec47474e2f9dfe8b4704911f8fb8112db2 100644 |
--- a/src/mips/code-stubs-mips.cc |
+++ b/src/mips/code-stubs-mips.cc |
@@ -1628,8 +1628,8 @@ void RegExpExecStub::Generate(MacroAssembler* masm) { |
__ lw(a0, MemOperand(sp, kLastMatchInfoOffset)); |
__ JumpIfSmi(a0, &runtime); |
__ GetObjectType(a0, a2, a2); |
- __ Branch(&runtime, ne, a2, Operand(JS_ARRAY_TYPE)); |
- // Check that the JSArray is in fast case. |
+ __ Branch(&runtime, ne, a2, Operand(JS_OBJECT_TYPE)); |
+ // Check that the object has fast elements. |
__ lw(last_match_info_elements, |
FieldMemOperand(a0, JSArray::kElementsOffset)); |
__ lw(a0, FieldMemOperand(last_match_info_elements, HeapObject::kMapOffset)); |